@@ -102,11 +102,12 @@ C If ISTATE .GT. 1 but the flag INIT shows that initialization has
 C not yet been done, an error return occurs.
 C If ISTATE = 1 and TOUT = T, return immediately.
 C-----------------------------------------------------------------------
-C
+C KARLINE: INITIALISED IHIT TO AVOID COMPILER WARNINGS - SHOULD HAVE NO EFFEXT
+      IHIT = .TRUE.
 C***FIRST EXECUTABLE STATEMENT  DLSODER
       IF (ISTATE .LT. 1 .OR. ISTATE .GT. 3) GO TO 601
       IF (ITASK .LT. 1 .OR. ITASK .GT. 5) GO TO 602
-C Karline: added nest sentence
+C Karline: added next  sentence
       ITASKC = ITASK
       IF (ISTATE .EQ. 1) GO TO 10
       IF (INIT .EQ. 0) GO TO 603
@@ -848,6 +849,8 @@ C If ISTATE .gt. 1 but the flag INIT shows that initialization has
 C not yet been done, an error return occurs.
 C If ISTATE = 1 and TOUT = T, return immediately.
 C-----------------------------------------------------------------------
+C KARLINE: INITIALISED IHIT TO AVOID COMPILER WARNINGS - SHOULD HAVE NO EFFEXT
+      IHIT = .TRUE.
       IF (ISTATE .LT. 1 .OR. ISTATE .GT. 3) GO TO 601
       IF (ITASK .LT. 1 .OR. ITASK .GT. 5) GO TO 602
 C Karline: added nest sentence
